#include <BTCA2ALite.h>

/*---------------------------------------------------------------------------------
 
 Пример для BTCA2ALite v1.0
 
 Авторы библиотеки: Сергей Зайцев (ZSeregaA) и Дмитрий Шумельчук
 Сайт проекта: http://robocontroller.ru/

 Данный пример демонстрирует работу библиотеки BTCA2ALite
 Эта библиотека обрабатывает команды посланные приложением BTController Lite
 Подробную информацию и инструкцию читайте тут http://robocontroller.ru/news/2013-11-05-35
 
 В данном примере будут использоваться 3 светодиода.
 В программе BTController Lite на андроид устройстве выберите джойстик snes
 Вы наглядно увидите работу основных функций библиотеки.
 Полный список поддерживаемых кнопок в Lite версии, ищите по ссылке выше.

---------------------------------------------------------------------------------*/

btca2aLite btca2aLite; // создаем BTCA2ALite класс

int LED1 = 2; // Пин светодиода 1
int LED2 = 3; // Пин светодиода 2
int LED3 = 4; // Пин светодиода 3

void setup() {
  
  // В библиотеке реализован выбор последовательных портов для подключения Bluetooth к Arduino Mega.
  // Если вы используете другую плату ардуино
  // тогда первое число в btca2aLite.SetupHardwareSerial(0, 115200) должен быть 0.
  // Если вы используете Arduino Mega или её аналоги, тогда вы можете выбрать номер нужного порта.
  // 1 - Serial1, 2 - Serial2, 3 - Serial3, 0 - основной Serial.
  // Например, Bluetooth модуль будет использовать Serial2
  // результат btca2aLite.SetupHardwareSerial(2, 115200)
  
  // ВАЖНО!!! Для нормальной работы библиотеки скорость сериал соединения должна быть 115200
  
  // Обязательная часть для работы библиотеки. Задает порт и скорость порта.
  btca2aLite.SetupHardwareSerial(0, 115200); // Номер порта, Скорость
  
  pinMode(LED1, OUTPUT); // Инициализируем пин светодиода 1
  pinMode(LED2, OUTPUT); // Инициализируем пин светодиода 2
  pinMode(LED3, OUTPUT); // Инициализируем пин светодиода 3
  digitalWrite(LED1, LOW); // Светодиод 1 выключен
  digitalWrite(LED2, LOW); // Светодиод 2 выключен
  digitalWrite(LED3, LOW); // Светодиод 3 выключен
}

void loop(){
  
  // Обязательная часть для работы библиотеки. Считывает принятые данные и изменяет статус кнопок.
  btca2aLite.ReadCommand();
  
  //------------------------ Button ---------------------------------
  // Button - считывает момент нажатия выбранной кнопки
  // В момент нажатия на джойстике кнопки X, светодиод загорится. 
  if (btca2aLite.Button(KEYCODE_BUTTON_X)){
    digitalWrite(LED1, HIGH);
  }
  
  // В момент нажатия на джойстике кнопки Y, светодиод погаснет.
  if (btca2aLite.Button(KEYCODE_BUTTON_Y)){
    digitalWrite(LED1, LOW);
  }
  
  //------------------------ ButtonPressed ---------------------------------
  // ButtonPressed - проверяет нажата ли выбранная кнопка
  // Светодиод будет гореть пока вы удерживаете кнопку A 
  if (btca2aLite.ButtonPressed(KEYCODE_BUTTON_A)){
    digitalWrite(LED2, HIGH);
  }
  else{
    digitalWrite(LED2, LOW);
  }
  
  //------------------------ ButtonReleased ---------------------------------
  // ButtonReleased - проверяет отпущена ли выбранная кнопка
  // Светодиод будет гореть пока вы удерживаете кнопку L1 и при этом не нажата кнопка L2 
  if (btca2aLite.ButtonPressed(KEYCODE_BUTTON_L1) && btca2aLite.ButtonReleased(KEYCODE_BUTTON_L2)){
    digitalWrite(LED3, HIGH);
  }
  else{
    digitalWrite(LED3, LOW);
  }
  
}
